@@ -34,7 +34,7 @@ qtScreen::qtScreen(QWidget *parent, const char *name, WFlags f)
 	setMouseTracking(true);
 	setCursor(QCursor(BlankCursor));
 
-	//QPEApplication::grabKeyboard();
+	QPEApplication::grabKeyboard();
 }
 
 void qtScreen::closeEvent(QCloseEvent *e)
