@@ -5,7 +5,7 @@ private:
 
 public:
 	qtScreen(QWidget *parent = 0, const char *name = 0, WFlags f = 0);
-	QImage *CreateShadowImage(DWORD *w, DWORD *h, int depth, void **bits, DWORD *stride);
+	QImage *CreateShadowImage(DWORD *w, DWORD *h, int *depth, void **bits, DWORD *stride);
 
 	//void RedrawScreen(int x, int y, int w, int h);
 
