@@ -238,8 +238,6 @@ if (fDebugProcMsg) \
  * Typedefs for engine dependent function pointers
  */
 
-typedef Bool (*qtAllocateFBProcPtr)(ScreenPtr);
-
 typedef void (*qtShadowUpdateProcPtr)(ScreenPtr, shadowBufPtr);
 
 typedef Bool (*qtCloseScreenProcPtr)(int, ScreenPtr);
@@ -454,7 +452,6 @@ typedef struct _qtPrivScreenRec
 	Bool			fServerStarted;
   
 	/* Engine specific functions */
-	qtAllocateFBProcPtr			pqtAllocateFB;
 	qtShadowUpdateProcPtr			pqtShadowUpdate;
 	qtCloseScreenProcPtr			pqtCloseScreen;
 	qtInitVisualsProcPtr			pqtInitVisuals;
