@@ -15,7 +15,7 @@ Priority: optional
 Section: Qtopia
 Maintainer: Takuya Murakami <tmurakam@mtd.biglobe.ne.jp>
 Architecture: arm
-Version: 0.0.2
+Version: 0.0.3
 Depends:
 Description: X/Qt Server 
  XFree86 server port over Qtopia.
@@ -32,7 +32,8 @@ mkdir -p opt/QtPalmtop/help/ja/html
 cp ../programs/Xserver/Xqt opt/QtPalmtop/bin
 cp ../programs/Xserver/hw/xqt/Xqt.desktop opt/QtPalmtop/apps/Applications
 cp ../programs/Xserver/hw/xqt/Xqt.png opt/QtPalmtop/pics
-iconv --to-code=utf8 ../Xqt.html > opt/QtPalmtop/help/html/Xqt.html
+cp ../Xqt.html opt/QtPalmtop/help/html
+iconv --to-code=utf8 ../Xqt.ja.html > opt/QtPalmtop/help/html/Xqt.ja.html
 
 cd ..
 ipkg-build .ipkg-work
